==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE58S.sql <==
/****************************************************************************/
/* GE58 ( RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2016/10/27 10:56:53                                            */
/****************************************************************************/

CREATE TABLE GE58 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID       VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID   */
 , CLM          VARCHAR (  30 )                 NOT NULL            /*  30 項目     */
 , KBOUT        VARCHAR (   1 )                 NOT NULL            /*  40 出力区分 */
 , DATA1        VARCHAR ( 100 )                                     /*  50 ﾃﾞｰﾀ1    */
 , DATA2        VARCHAR (  10 )                                     /*  60 ﾃﾞｰﾀ2    */
 , DATA3        VARCHAR (  10 )                                     /*  70 ﾃﾞｰﾀ3    */
 , DATA4        VARCHAR (  10 )                                     /*  80 ﾃﾞｰﾀ4    */
 , DATA5        VARCHAR (  10 )                                     /*  90 ﾃﾞｰﾀ5    */
 , DATA6        VARCHAR (  10 )                                     /* 100 ﾃﾞｰﾀ6    */
 , DATA7        VARCHAR (  10 )                                     /* 110 ﾃﾞｰﾀ7    */
 , DATA8        VARCHAR (  10 )                                     /* 120 ﾃﾞｰﾀ8    */
 , DATA9        VARCHAR (  10 )                                     /* 130 ﾃﾞｰﾀ9    */
 , DATA10       VARCHAR (  10 )                                     /* 140 ﾃﾞｰﾀ10   */
 , DATA11       VARCHAR (  10 )                                     /* 150 ﾃﾞｰﾀ11   */
 , DATA12       VARCHAR (  10 )                                     /* 160 ﾃﾞｰﾀ12   */
 , DATA13       VARCHAR (  10 )                                     /* 170 ﾃﾞｰﾀ13   */
 , DATA14       VARCHAR (  10 )                                     /* 180 ﾃﾞｰﾀ14   */
 , DATA15       VARCHAR (  10 )                                     /* 190 ﾃﾞｰﾀ15   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時 */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成社員 */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者   */
);

==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/POSTGRES/sql/install/01_TABLE/GE58S.sql <==
/****************************************************************************/
/* GE58 ( RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:31                                            */
/****************************************************************************/

CREATE TABLE GE58 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID       VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID   */
 , CLM          VARCHAR (  30 )                 NOT NULL            /*  30 項目     */
 , KBOUT        VARCHAR (   1 )                 NOT NULL            /*  40 出力区分 */
 , DATA1        VARCHAR ( 100 )                                     /*  50 ﾃﾞｰﾀ1    */
 , DATA2        VARCHAR (  10 )                                     /*  60 ﾃﾞｰﾀ2    */
 , DATA3        VARCHAR (  10 )                                     /*  70 ﾃﾞｰﾀ3    */
 , DATA4        VARCHAR (  10 )                                     /*  80 ﾃﾞｰﾀ4    */
 , DATA5        VARCHAR (  10 )                                     /*  90 ﾃﾞｰﾀ5    */
 , DATA6        VARCHAR (  10 )                                     /* 100 ﾃﾞｰﾀ6    */
 , DATA7        VARCHAR (  10 )                                     /* 110 ﾃﾞｰﾀ7    */
 , DATA8        VARCHAR (  10 )                                     /* 120 ﾃﾞｰﾀ8    */
 , DATA9        VARCHAR (  10 )                                     /* 130 ﾃﾞｰﾀ9    */
 , DATA10       VARCHAR (  10 )                                     /* 140 ﾃﾞｰﾀ10   */
 , DATA11       VARCHAR (  10 )                                     /* 150 ﾃﾞｰﾀ11   */
 , DATA12       VARCHAR (  10 )                                     /* 160 ﾃﾞｰﾀ12   */
 , DATA13       VARCHAR (  10 )                                     /* 170 ﾃﾞｰﾀ13   */
 , DATA14       VARCHAR (  10 )                                     /* 180 ﾃﾞｰﾀ14   */
 , DATA15       VARCHAR (  10 )                                     /* 190 ﾃﾞｰﾀ15   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時 */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成者   */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                     /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                     /* 890 更新者   */
);
